summaryrefslogtreecommitdiffstats
path: root/kword/KWTextParag.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kword/KWTextParag.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kword/KWTextParag.h')
-rw-r--r--kword/KWTextParag.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kword/KWTextParag.h b/kword/KWTextParag.h
index 9e3ffe27..db873c24 100644
--- a/kword/KWTextParag.h
+++ b/kword/KWTextParag.h
@@ -23,7 +23,7 @@
#include "KoTextParag.h"
class KoStyleCollection;
-class QDomDocument;
+class TQDomDocument;
class KWTextFrameSet;
class KWTextDocument;
class KWDocument;
@@ -46,7 +46,7 @@ public:
KWTextDocument * kwTextDocument() const;
- virtual void setParagLayout( const KoParagLayout &layout, int flags = KoParagLayout::All, int marginIndex = -1 );
+ virtual void setParagLayout( const KoParagLayout &tqlayout, int flags = KoParagLayout::All, int marginIndex = -1 );
/** The type of page-breaking behaviour */
void setPageBreaking( int pb ); // warning this sets all the flags!
@@ -56,40 +56,40 @@ public:
bool hardFrameBreakAfter() const { return m_layout.pageBreaking & KoParagLayout::HardFrameBreakAfter; }
/** Public for loading a style (KWord-1.3 XML) */
- static KoTextFormat loadFormat( QDomElement &formatElem, KoTextFormat *refFormat, const QFont &defaultFont, const QString & defaultLanguage, bool hyphanation );
+ static KoTextFormat loadFormat( TQDomElement &formatElem, KoTextFormat *refFormat, const TQFont &defaultFont, const TQString & defaultLanguage, bool hyphanation );
/** Public for saving a style (KWord-1.3 XML) */
- static QDomElement saveFormat( QDomDocument &doc, KoTextFormat *curFormat, KoTextFormat *refFormat, int pos, int len );
+ static TQDomElement saveFormat( TQDomDocument &doc, KoTextFormat *curFormat, KoTextFormat *refFormat, int pos, int len );
/** Save (to KWord-1.3 XML) the whole paragraph */
- void save( QDomElement &parentElem, bool saveAnchorsFramesets = false );
+ void save( TQDomElement &tqparentElem, bool saveAnchorsFramesets = false );
/** Save (to KWord-1.3 XML) a portion of the paragraph */
- void save( QDomElement &parentElem, int from, int to, bool saveAnchorsFramesets = false );
+ void save( TQDomElement &tqparentElem, int from, int to, bool saveAnchorsFramesets = false );
/** Load (from KWord-1.3 XML) the paragraph */
- void load( QDomElement &attributes );
+ void load( TQDomElement &attributes );
/** Load (from KWord-1.3 XML) and apply \<FORMAT\> tags (used by KWTextParag::load and by KWPasteCommand) */
- void loadFormatting( QDomElement &attributes, int offset = 0, bool loadFootNote=true );
+ void loadFormatting( TQDomElement &attributes, int offset = 0, bool loadFootNote=true );
- /** Load (from KWord-1.3 XML) and apply paragraph layout */
- void loadLayout( QDomElement & attributes );
+ /** Load (from KWord-1.3 XML) and apply paragraph tqlayout */
+ void loadLayout( TQDomElement & attributes );
/** Load (from KWord-1.3 XML), optionally using styles from document. */
- static KoParagLayout loadParagLayout( QDomElement & parentElem, KWDocument *doc, bool useRefStyle );
+ static KoParagLayout loadParagLayout( TQDomElement & tqparentElem, KWDocument *doc, bool useRefStyle );
- virtual void loadOasis( const QDomElement& e, KoOasisContext& context, KoStyleCollection *styleCollection, uint& pos );
+ virtual void loadOasis( const TQDomElement& e, KoOasisContext& context, KoStyleCollection *styleCollection, uint& pos );
virtual void saveOasis( KoXmlWriter& writer, KoSavingContext& context,
int from, int to, bool saveAnchorsFramesets = false ) const;
virtual void join( KoTextParag *parag );
protected:
- virtual void drawFormattingChars( QPainter &painter, int start, int len,
+ virtual void drawFormattingChars( TQPainter &painter, int start, int len,
int lastY_pix, int baseLine_pix, int h_pix, // in pixels
bool drawSelections,
- KoTextFormat *lastFormat, const QMemArray<int> &selectionStarts,
- const QMemArray<int> &selectionEnds, const QColorGroup &cg,
+ KoTextFormat *lastFormat, const TQMemArray<int> &selectionStarts,
+ const TQMemArray<int> &selectionEnds, const TQColorGroup &cg,
bool rightToLeft, int line, KoTextZoomHandler* zh,
int whichFormattingChars );